from setuptools import setup

with open('README.rst') as file:
    long_description = file.read()

setup(name='tset',
      description='time sets for Python',
      long_description=long_description,
      license='MIT',
      author='Aaron Schumacher',
      author_email='ajschumacher@gmail.com',
      url='https://github.com/ajschumacher/tset',
      download_url='https://github.com/ajschumacher/tset/tarball/0.1',
      version='0.1')
